==> owncloud-10.0.7.tgz: owncloud/apps/files/l10n/hu_HU.js <==
OC.L10N.register(
    "files",
    {
    "Storage invalid" : "A tároló érvénytelen",
    "Unknown error" : "Ismeretlen hiba",
    "All files" : "Az összes állomány",
    "Saved" : "Elmentve!",
    "Home" : "Otthoni",
    "Close" : "Bezárás",
    "Favorites" : "Kedvencek",
    "Could not create folder \"{dir}\"" : "{dir} könyvtár nem létrehozható",
    "Upload cancelled." : "A feltöltést megszakítottuk.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "A(z) {filename} állomány nem tölthető fel, mert ez vagy egy mappa, vagy pedig 0 bájtból áll.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nincs elég szabad hely. A feltöltés mérete {size1}, de csak ennyi hely van: {size2}.",
    "Uploading..." : "Feltöltés...",
    "..." : "...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Fájlfeltöltés van folyamatban. Az oldal elhagyása megszakítja a feltöltést.",
    "Actions" : "Műveletek",
    "Download" : "Letöltés",
    "Rename" : "Átnevezés",
    "Delete" : "Törlés",
    "Disconnect storage" : "Tároló leválasztása",
    "Unshare" : "A megosztás visszavonása",
    "Files" : "Fájlkezelő",
    "Details" : "Részletek",
    "Select" : "Kiválaszt",
    "Pending" : "Folyamatban",
    "Unable to determine date" : "Nem lehet meghatározni a dátumot",
    "Invalid path" : "Érvénytelen útvonal",
    "This operation is forbidden" : "Tiltott művelet",
    "This directory is unavailable, please check the logs or contact the administrator" : "Ez a könyvtár nem elérhető, kérem nézze meg a naplófájlokat vagy keresse az adminisztrátort",
    "Could not move \"{file}\", target exists" : "{file} fájl nem áthelyezhető, mert a cél már létezik",
    "Could not move \"{file}\"" : "{file} fájl nem áthelyezhető",
    "{newName} already exists" : "{newName} már létezik",
    "Could not rename \"{fileName}\", it does not exist any more" : "Nem átnevezhető erre: {fileName}, mert már nem létezik",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "{targetName} már használatban van a(z) {dir} könyvtárban. Kérjük, válassz másik nevet.",
    "Could not rename \"{fileName}\"" : "{fileName} fájl nem átnevezhető",
    "Could not create file \"{file}\"" : "{file} fájl nem létrehozható",
    "Could not create file \"{file}\" because it already exists" : "{file} fájl nem létrehozható, mert már létezik",
    "Could not create folder \"{dir}\" because it already exists" : "{dir} könyvtár nem létrehozható, mert már létezik",
    "Error deleting file \"{fileName}\"." : "Hiba történt {fileName} fájl törlése közben.",
    "Name" : "Név",
    "Size" : "Méret",
    "Modified" : "Módosítva",
    "_%n folder_::_%n folders_" : ["%n mappa","%n mappa"],
    "_%n file_::_%n files_" : ["%n állomány","%n állomány"],
    "{dirs} and {files}" : "{dirs} és {files}",
    "You don’t have permission to upload or create files here" : "Önnek nincs jogosultsága ahhoz, hogy ide állományokat töltsön föl, vagy itt újakat hozzon létre",
    "_Uploading %n file_::_Uploading %n files_" : ["%n állomány feltöltése","%n állomány feltöltése"],
    "New" : "Új",
    "\"{name}\" is an invalid file name." : "\"{name}\" érvénytelen, mint fájlnév.",
    "File name cannot be empty." : "A fájlnév nem lehet semmi.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "A {owner} felhasználó tárolója betelt, a fájlok nem frissíthetők és szinkronizálhatók többet!",
    "Your storage is full, files can not be updated or synced anymore!" : "A tároló tele van, a fájlok nem frissíthetőek vagy szinkronizálhatóak a jövőben.",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "A {owner} felhasználó tárolója majdnem betelt ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "A tároló majdnem tele van ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["egyezések '{filter}'","egyezés '{filter}'"],
    "Path" : "Útvonal",
    "_%n byte_::_%n bytes_" : ["%n bájt","%n bájt"],
    "Favorited" : "Kedvenc",
    "Favorite" : "Kedvenc",
    "Folder" : "Mappa",
    "New folder" : "Új mappa",
    "{newname} already exists" : "{newname} már létezik",
    "Upload" : "Feltöltés",
    "An error occurred while trying to update the tags" : "Hiba történt, miközben megpróbálta frissíteni a címkéket",
    "A new file or folder has been <strong>created</strong>" : "Új fájl vagy könyvtár <strong>létrehozása</strong>",
    "A file or folder has been <strong>changed</strong>" : "Fájl vagy könyvtár <strong>módosítása</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Szűkítse le az értesítéseket a létrehozásról és a változásokról a <strong>kedvenc fájlok</strong> <em>(Stream only)</em> -ra",
    "A file or folder has been <strong>deleted</strong>" : "Fájl vagy könyvtár <strong>törlése</strong>",
    "A file or folder has been <strong>restored</strong>" : "Fájl vagy könyvtár <strong>visszatöltése</strong>",
    "You created %1$s" : "Létrehoztam: %1$s",
    "%2$s created %1$s" : "%2$s létrehozta: %1$s",
    "%1$s was created in a public folder" : "Nyilvános mappában hozták létre: %1$s",
    "You changed %1$s" : "Megváltoztattam: %1$s",
    "%2$s changed %1$s" : "%2$s megváltoztatta: %1$s",
    "You deleted %1$s" : "Töröltem: %1$s",
    "%2$s deleted %1$s" : "%2$s törölte: %1$s",
    "You restored %1$s" : "Visszatöltötted %1$s",
    "%2$s restored %1$s" : "%1$s visszatöltötte %2$s",
    "Changed by %2$s" : "Megváltoztatta: %2$s",
    "Deleted by %2$s" : "Törölte: %2$s",
    "Restored by %2$s" : "Visszaállította: %2$s",
    "Upload (max. %s)" : "Feltöltés (max.: %s)",
    "File handling" : "Fájlkezelés",
    "Maximum upload size" : "Maximális feltölthető fájlméret",
    "max. possible: " : "max. lehetséges: ",
    "Save" : "Mentés",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "PHP-FPM-mel akár 5 percbe is telhet, míg ez a beállítás érvénybe lép.",
    "Missing permissions to edit from here." : "Innen nem lehet szerkeszteni hiányzó jogosultság miatt.",
    "Settings" : "Beállítások",
    "Show hidden files" : "Rejtett fájlok megjelenítése",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Használja ezt a címet <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">a Fájlok eléréséhez WebDAV-on keresztül</a>.",
    "No files in here" : "Itt nincsenek fájlok",
    "Upload some content or sync with your devices!" : "Tölts fel néhány tartalmat, vagy szinkronizálj az eszközöddel!",
    "No entries found in this folder" : "Nincsenek bejegyzések ebben a könyvtárban",
    "Select all" : "Összes kijelölése",
    "Upload too large" : "A feltöltés túl nagy",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "A feltöltendő állományok mérete meghaladja a kiszolgálón megengedett maximális méretet.",
    "No favorites" : "Nincsenek kedvencek",
    "Files and folders you mark as favorite will show up here" : "A kedvencnek jelölt fájlokat és mappákat itt találod meg",
    "Text file" : "Szövegfájl",
    "New text file.txt" : "Új szöveges fájl.txt"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.10.tgz: owncloud/apps/files/l10n/hu_HU.js <==
OC.L10N.register(
    "files",
    {
    "Storage invalid" : "A tároló érvénytelen",
    "Unknown error" : "Ismeretlen hiba",
    "All files" : "Az összes állomány",
    "Saved" : "Elmentve!",
    "Home" : "Otthoni",
    "Close" : "Bezárás",
    "Favorites" : "Kedvencek",
    "Could not create folder \"{dir}\"" : "{dir} könyvtár nem létrehozható",
    "Upload cancelled." : "A feltöltést megszakítottuk.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "A(z) {filename} állomány nem tölthető fel, mert ez vagy egy mappa, vagy pedig 0 bájtból áll.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nincs elég szabad hely. A feltöltés mérete {size1}, de csak ennyi hely van: {size2}.",
    "Uploading..." : "Feltöltés...",
    "..." : "...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Fájlfeltöltés van folyamatban. Az oldal elhagyása megszakítja a feltöltést.",
    "Actions" : "Műveletek",
    "Download" : "Letöltés",
    "Rename" : "Átnevezés",
    "Delete" : "Törlés",
    "Disconnect storage" : "Tároló leválasztása",
    "Unshare" : "A megosztás visszavonása",
    "Files" : "Fájlkezelő",
    "Details" : "Részletek",
    "Select" : "Kiválaszt",
    "Pending" : "Folyamatban",
    "Unable to determine date" : "Nem lehet meghatározni a dátumot",
    "Invalid path" : "Érvénytelen útvonal",
    "This operation is forbidden" : "Tiltott művelet",
    "This directory is unavailable, please check the logs or contact the administrator" : "Ez a könyvtár nem elérhető, kérem nézze meg a naplófájlokat vagy keresse az adminisztrátort",
    "Could not move \"{file}\", target exists" : "{file} fájl nem áthelyezhető, mert a cél már létezik",
    "Could not move \"{file}\"" : "{file} fájl nem áthelyezhető",
    "{newName} already exists" : "{newName} már létezik",
    "Could not rename \"{fileName}\", it does not exist any more" : "Nem átnevezhető erre: {fileName}, mert már nem létezik",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "{targetName} már használatban van a(z) {dir} könyvtárban. Kérjük, válassz másik nevet.",
    "Could not rename \"{fileName}\"" : "{fileName} fájl nem átnevezhető",
    "Could not create file \"{file}\"" : "{file} fájl nem létrehozható",
    "Could not create file \"{file}\" because it already exists" : "{file} fájl nem létrehozható, mert már létezik",
    "Could not create folder \"{dir}\" because it already exists" : "{dir} könyvtár nem létrehozható, mert már létezik",
    "Error deleting file \"{fileName}\"." : "Hiba történt {fileName} fájl törlése közben.",
    "Name" : "Név",
    "Size" : "Méret",
    "Modified" : "Módosítva",
    "_%n folder_::_%n folders_" : ["%n mappa","%n mappa"],
    "_%n file_::_%n files_" : ["%n állomány","%n állomány"],
    "{dirs} and {files}" : "{dirs} és {files}",
    "You don’t have permission to upload or create files here" : "Önnek nincs jogosultsága ahhoz, hogy ide állományokat töltsön föl, vagy itt újakat hozzon létre",
    "_Uploading %n file_::_Uploading %n files_" : ["%n állomány feltöltése","%n állomány feltöltése"],
    "New" : "Új",
    "\"{name}\" is an invalid file name." : "\"{name}\" érvénytelen, mint fájlnév.",
    "File name cannot be empty." : "A fájlnév nem lehet semmi.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "A {owner} felhasználó tárolója betelt, a fájlok nem frissíthetők és szinkronizálhatók többet!",
    "Your storage is full, files can not be updated or synced anymore!" : "A tároló tele van, a fájlok nem frissíthetőek vagy szinkronizálhatóak a jövőben.",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "A {owner} felhasználó tárolója majdnem betelt ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "A tároló majdnem tele van ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["egyezések '{filter}'","egyezés '{filter}'"],
    "Path" : "Útvonal",
    "_%n byte_::_%n bytes_" : ["%n bájt","%n bájt"],
    "Favorited" : "Kedvenc",
    "Favorite" : "Kedvenc",
    "Folder" : "Mappa",
    "New folder" : "Új mappa",
    "{newname} already exists" : "{newname} már létezik",
    "Upload" : "Feltöltés",
    "An error occurred while trying to update the tags" : "Hiba történt, miközben megpróbálta frissíteni a címkéket",
    "A new file or folder has been <strong>created</strong>" : "Új fájl vagy könyvtár <strong>létrehozása</strong>",
    "A file or folder has been <strong>changed</strong>" : "Fájl vagy könyvtár <strong>módosítása</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Szűkítse le az értesítéseket a létrehozásról és a változásokról a <strong>kedvenc fájlok</strong> <em>(Stream only)</em> -ra",
    "A file or folder has been <strong>deleted</strong>" : "Fájl vagy könyvtár <strong>törlése</strong>",
    "A file or folder has been <strong>restored</strong>" : "Fájl vagy könyvtár <strong>visszatöltése</strong>",
    "You created %1$s" : "Létrehoztam: %1$s",
    "%2$s created %1$s" : "%2$s létrehozta: %1$s",
    "%1$s was created in a public folder" : "Nyilvános mappában hozták létre: %1$s",
    "You changed %1$s" : "Megváltoztattam: %1$s",
    "%2$s changed %1$s" : "%2$s megváltoztatta: %1$s",
    "You deleted %1$s" : "Töröltem: %1$s",
    "%2$s deleted %1$s" : "%2$s törölte: %1$s",
    "You restored %1$s" : "Visszatöltötted %1$s",
    "%2$s restored %1$s" : "%1$s visszatöltötte %2$s",
    "Changed by %2$s" : "Megváltoztatta: %2$s",
    "Deleted by %2$s" : "Törölte: %2$s",
    "Restored by %2$s" : "Visszaállította: %2$s",
    "Upload (max. %s)" : "Feltöltés (max.: %s)",
    "File handling" : "Fájlkezelés",
    "Maximum upload size" : "Maximális feltölthető fájlméret",
    "max. possible: " : "max. lehetséges: ",
    "Save" : "Mentés",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "PHP-FPM-mel akár 5 percbe is telhet, míg ez a beállítás érvénybe lép.",
    "Missing permissions to edit from here." : "Innen nem lehet szerkeszteni hiányzó jogosultság miatt.",
    "Settings" : "Beállítások",
    "Show hidden files" : "Rejtett fájlok megjelenítése",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Használja ezt a címet <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">a Fájlok eléréséhez WebDAV-on keresztül</a>.",
    "No files in here" : "Itt nincsenek fájlok",
    "Upload some content or sync with your devices!" : "Tölts fel néhány tartalmat, vagy szinkronizálj az eszközöddel!",
    "No entries found in this folder" : "Nincsenek bejegyzések ebben a könyvtárban",
    "Select all" : "Összes kijelölése",
    "Upload too large" : "A feltöltés túl nagy",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "A feltöltendő állományok mérete meghaladja a kiszolgálón megengedett maximális méretet.",
    "No favorites" : "Nincsenek kedvencek",
    "Files and folders you mark as favorite will show up here" : "A kedvencnek jelölt fájlokat és mappákat itt találod meg",
    "Text file" : "Szövegfájl",
    "New text file.txt" : "Új szöveges fájl.txt",
    "File could not be found" : "Az állomány nem található",
    "Target folder does not exist any more" : "A cél mappa nem létezik már",
    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "Privát hivatkozás: Csak azok használhatják, akik hozzáférhetnek a fájlokhoz/mappákhoz. Használja az állandó hivatkozást maga, vagy rendelje hozzá más fájlokhoz a megosztáson belül ",
    "Upload timeout for file \"{file}\"" : "Időtúllépés az állomány feltöltésekor \"{file}\"",
    "Storage is temporarily not available" : "A tároló átmenetileg nem elérhető",
    "Processing files..." : "Állományok feldolgozása...",
    "{loadedSize} of {totalSize} ({bitrate})" : "({bitrate}) {totalSize} -nak a {loadedSize} ",
    "No entries in this folder match {filter}" : "Nincsenek elemek, ebben a mappa összehasonlításban {filter}",
    "Limit notifications about creation and changes to your <strong>favorite files</strong>" : "Korlát értesítések a <strong>kedvenc fájlok</strong> létrehozása és változtatása ügyében",
    "You don't have permissions to access this file/folder - Please contact the owner to share it with you." : "Önnek nincsen engedélye, hogy hozzáférjen ehhez a fájlhoz/mappához - Kérjük, hogy vegye fel a kapcsolatot a tulajdonossal, hogy azt megossza Önnel.",
    "Error when assembling chunks, status code {status}" : "Hiba lépett fel a darabok összeállítása közben, státusz kód {status}",
    "Not enough free space" : "Nincs elég szabad hely"
},
"nplurals=2; plural=(n != 1);");
